pubspec='pubspec.yaml'
readme='README.md'
version="$(git describe --long | awk '{split($0,a,"-"); print a[1] "." a[2] "." a[3]}' | awk '{split($0,a,"."); print a[1] "." a[2] "." a[3] + a[4]}')"

update_version()
{
    echo ''
    echo 'looking for version line...'
    echo ''
    while read line; do
    if [[ $line == $2:* ]]; then
    echo $line
        echo "LINE FOUND IN $1"
        sed -i "" "s/$line/$2: $version/" $1
        return
    fi

    done < $1
}

update_versions(){
    update_version $pubspec version
    update_version $readme capturesdk
}

generate_constants()
{
    echo 'Generating Constants...'
    echo ''
    python3 constants/buildscripts/createErrors.py Dart constants/errors.json templates/errors_template.dart lib/classes/gen/errors.dart ble
    python3 constants/buildscripts/createDataSources.py Dart constants/dataSourceIds.json templates/datasources_template.dart lib/classes/gen/data_sources.dart ble
    python3 constants/buildscripts/createDeviceTypes.py Dart constants/deviceTypes.json templates/device_types_template.dart lib/classes/gen/device_types.dart ble
    python3 constants/buildscripts/createEventIds.py Dart constants/eventIDs.json templates/events_template.dart lib/classes/gen/event_ids.dart ble
    python3 constants/buildscripts/createPropertyIds.py Dart constants/propertyIDs.json templates/properties_template.dart lib/classes/gen/property_ids.dart ble
}

get_constants()
{
    echo 'Getting Constants...'
    echo ''
    git subtree pull --prefix=constants git@git.socketmobile.com:scanning/captureconstants-universal.git master --squash
    echo ''
    echo 'Constants retreived from subtree.'
}

prepare_for_publush(){
    echo 'UPDATING VERSIONS'
    echo ''
    update_versions
    echo ''
    flutter clean && cd example && flutter clean && cd .. && dart pub publish --dry-run
    echo 'Done.'
}


init(){
    echo 'Would you like to update the package version, get constants, generate constants, or publish flutter package? (version/get/gen/pub)'
    read answer
    lowerstr=$(echo $answer | tr '[:upper:]' '[:lower:]')
    if [[ "$lowerstr" == "version" ]] ;then 
        update_versions
    elif [[ "$lowerstr" == "gen" ]] ;then
        generate_constants
    elif [[ "$lowerstr" == "get" ]] ;then
        get_constants
    elif [[ "$lowerstr" == "pub" ]] ;then
        prepare_for_publush
    else 
        echo 'Invalid command.'
    fi
}

init